@@ -11,5 +11,9 @@ def new(column: str):
     typer.echo(f"Creating new column: {column}")
 
 
-if __name__ == "__main__":
+def main():
     app()
+
+
+if __name__ == "__main__":
+    main()
